@@ -21,13 +21,21 @@
 #ifndef __GWEATHER_H__
 #define __GWEATHER_H__
 
-#ifndef GWEATHER_I_KNOW_THIS_IS_UNSTABLE
+#if !(defined(GWEATHER_COMPILATION) || defined(GWEATHER_I_KNOW_THIS_IS_UNSTABLE))
 #error "libgweather should only be used if you understand that it's subject to change, and is not supported as a fixed API/ABI or as part of the platform"
 #endif
 
+#define IN_GWEATHER_H
+
+#include <libgweather/gweather-version.h>
+#include <libgweather/gweather-enums.h>
+#include <libgweather/gweather-enum-types.h>
 #include <libgweather/gweather-location.h>
 #include <libgweather/gweather-timezone.h>
 #include <libgweather/gweather-weather.h>
-#include <libgweather/location-entry.h>
+#include <libgweather/gweather-location-entry.h>
+#include <libgweather/gweather-timezone-menu.h>
+
+#undef IN_GWEATHER_H
 
 #endif /* __GWEATHER_H__ */
